package com.rathravane.drumlin.service.framework.context;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.Logger;

import com.rathravane.drumlin.service.framework.rendering.DrumlinRenderContext;
import com.rathravane.drumlin.service.standards.HttpStatusCodes;
import com.rathravane.till.logging.rrLogSetup;

class StdRenderer implements DrumlinRenderContext
{
	StdRenderer ( DrumlinRequestContext hc )
	{
		fContext = hc;
	}

	@Override
	public Object get ( String key )
	{
		return fContext.fLocalContext.get ( key );
	}

	@Override
	public void put ( String key, Object o )
	{
		fContext.fLocalContext.put ( key, o );
	}

	@Override
	public void remove ( String key )
	{
		fContext.fLocalContext.remove ( key );
	}

	@Override
	public void renderTemplate ( String templateName )
	{
		renderTemplate ( templateName, "text/html" );
	}

	@Override
	public void renderTemplate ( String templateName, String contentType )
	{
		try
		{
			if ( fContext.fSession != null )
			{
				final HashMap<String, Object> context = new HashMap<String, Object> ();
				fContext.fSession.buildTemplateContext ( context );
				for ( Map.Entry<String, Object> e : context.entrySet () )
				{
					put ( e.getKey (), e.getValue () );
				}
			}
			
			final PrintWriter out = fContext.response().getStreamForTextResponse ( contentType );
			fContext.merge ( templateName, fContext.fLocalContext, out );
		}
		catch ( Exception e )
		{
			fContext.response ().sendError ( HttpStatusCodes.k500_internalServerError, e.getMessage () );

			final StringWriter sw = new StringWriter ();
			final PrintWriter pw = new PrintWriter ( sw );
			e.printStackTrace ( pw );
			pw.close ();
			log.severe ( sw.toString () );
		}
	}

	private final DrumlinRequestContext fContext;
	static Logger log = rrLogSetup.getLog ( StdRenderer.class );
}