/*
 *	Copyright 2006-2012, Rathravane LLC
 *
 *	Licensed under the Apache License, Version 2.0 (the "License");
 *	you may not use this file except in compliance with the License.
 *	You may obtain a copy of the License at
 *	
 *	http://www.apache.org/licenses/LICENSE-2.0
 *	
 *	Unless required by applicable law or agreed to in writing, software
 *	distributed under the License is distributed on an "AS IS" BASIS,
 *	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *	See the License for the specific language governing permissions and
 *	limitations under the License.
 */
package com.rathravane.drumlin.service.framework.routing.playish;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.List;

import com.rathravane.drumlin.service.framework.context.DrumlinRequestContext;
import com.rathravane.till.data.rrStreamTools;

public class StaticFileHandler implements DrumlinPlayishRouteHandler
{
	public static final String kMaxAge = "drumlin.staticFile.cache.maxAgeSeconds";

	public StaticFileHandler ( String staticPageInfo, String ct )
	{
		fFile = staticPageInfo;
		fContentType = ct;
	}

	@Override
	public void handle ( DrumlinRequestContext context, List<String> args ) throws IOException
	{
		// expiry. currently global.
		final int cacheMaxAge = context.systemSettings ().getInt ( kMaxAge, -1 );
		if ( cacheMaxAge > 0 )
		{
			context.response().writeHeader ( "Cache-Control", "max-age=" + cacheMaxAge, true );
		}

		final File f = context.getServlet ().findFile ( fFile );
		rrStreamTools.copyStream (
			new FileInputStream ( f ),
			context.response ().getStreamForBinaryResponse ( fContentType )
		);
	}

	@Override
	public boolean actionMatches(String fullPath)
	{
		return false;
	}

	private final String fFile;
	private final String fContentType;
}
